:orphan:

.. Copyright (C) 2015-2016 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2015      Hartmut Goebel <h.goebel@crazy-compilers.com>
.. Copyright (C) 2015-2019 Robin Schneider <ypid@riseup.net>
.. Copyright (C) 2015-2019 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

.. _ownCloud documents application: https://apps.owncloud.com/content/show.php/Documents?content=168711
.. _ownCloud System Requirements: https://doc.owncloud.org/server/9.0/admin_manual/installation/system_requirements.html
